@@ -26,13 +26,6 @@ class BDSExcelDriver:
             wb.create_sheet(sheet_name)
         sheet = wb[sheet_name]
         result = sheet[column + row].value
+        if(result == '${EMPTY}'):
+            result = ''
         return result
-        
-    @keyword
-    def _set_global_variable_from_existing_excel(self, name, column='A', row='1', sheet_name='Sheet1'):
-        wb = load_workbook(self.file)
-        if(wb.sheetnames.count(sheet_name) == 0):
-            wb.create_sheet(sheet_name)
-        sheet = wb[sheet_name]
-        result = sheet[column + row].value
-        BuiltIn().set_global_variable(name, result)
